Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(44)

Unified Diff: src/spaces.cc

Issue 325343003: Revert "Rename kIs64BitArch with kRequiresCodeRange." (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/globals.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/spaces.cc
diff --git a/src/spaces.cc b/src/spaces.cc
index 9d2152970881694e46f0d5f6eecbef971f3894a8..7966a04728c6291e83142eeeda1acf2039c68c77 100644
--- a/src/spaces.cc
+++ b/src/spaces.cc
@@ -115,17 +115,15 @@ bool CodeRange::SetUp(size_t requested) {
ASSERT(code_range_ == NULL);
if (requested == 0) {
- // When a target requires the code range feature, we put all code objects
- // in a kMaximalCodeRangeSize range of virtual address space, so that
- // they can call each other with near calls.
- if (kRequiresCodeRange) {
- requested = kMaximalCodeRangeSize;
+ // On 64-bit platform(s), we put all code objects in a 512 MB range of
+ // virtual address space, so that they can call each other with near calls.
+ if (kIs64BitArch) {
+ requested = 512 * MB;
} else {
return true;
}
}
- ASSERT(requested <= kMaximalCodeRangeSize);
code_range_ = new VirtualMemory(requested);
CHECK(code_range_ != NULL);
if (!code_range_->IsReserved()) {
« no previous file with comments | « src/globals.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698